// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { DefaultTokenStore, TokenOrchestrator, CognitoUserPoolTokenRefresher, } from '@aws-amplify/auth/cognito';
/**
 * Creates an object that implements {@link TokenProvider}.
 * @param authConfig The Auth config that the credentials provider needs to function.
 * @param keyValueStorage An object that implements the {@link KeyValueStorageInterface}.
 * @returns An object that implements {@link TokenProvider}.
 */
export var createUserPoolsTokenProvider = function (authConfig, keyValueStorage) {
    var authTokenStore = new DefaultTokenStore();
    authTokenStore.setAuthConfig(authConfig);
    authTokenStore.setKeyValueStorage(keyValueStorage);
    var tokenOrchestrator = new TokenOrchestrator();
    tokenOrchestrator.setAuthConfig(authConfig);
    tokenOrchestrator.setAuthTokenStore(authTokenStore);
    tokenOrchestrator.setTokenRefresher(CognitoUserPoolTokenRefresher);
    return {
        getTokens: function (_a) {
            var _b = _a === void 0 ? { forceRefresh: false } : _a, forceRefresh = _b.forceRefresh;
            return tokenOrchestrator.getTokens({ forceRefresh: forceRefresh });
        },
    };
};
