// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { __awaiter, __generator } from "tslib";
import { createAmplifyServerContext, destroyAmplifyServerContext, } from '@aws-amplify/core/internals/adapter-core';
/**
 * The low level function that supports framework specific helpers.
 * It creates an Amplify server context based on the input and runs the operation
 * with injecting the context, and finally returns the result of the operation.
 *
 * @param amplifyConfig The Amplify resource config.
 * @param libraryOptions The Amplify library options.
 * @param operation The operation to run with the server context created from
 *   `amplifyConfig` and `libraryOptions`.
 * @returns The result returned by the `operation`.
 */
export var runWithAmplifyServerContext = function (amplifyConfig, libraryOptions, operation) { return __awaiter(void 0, void 0, void 0, function () {
    var contextSpec, result;
    return __generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                contextSpec = createAmplifyServerContext(amplifyConfig, libraryOptions);
                return [4 /*yield*/, operation(contextSpec)];
            case 1:
                result = _a.sent();
                destroyAmplifyServerContext(contextSpec);
                return [2 /*return*/, result];
        }
    });
}); };
