// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { __assign } from "tslib";
export var defaultSetCookieOptions = {
    sameSite: 'strict',
    secure: true,
};
var ONE_YEAR_IN_MS = 365 * 24 * 60 * 60 * 1000;
/**
 * Creates a Key Value storage interface using the `cookieStorageAdapter` as the
 * underlying storage.
 * @param cookieStorageAdapter An implementation of the `Adapter` in {@link CookieStorage}.
 * @returns An object that implements {@link KeyValueStorageInterface}.
 */
export var createKeyValueStorageFromCookieStorageAdapter = function (cookieStorageAdapter) {
    return {
        setItem: function (key, value) {
            // TODO(HuiSF): follow up the default CookieSerializeOptions values
            cookieStorageAdapter.set(key, value, __assign(__assign({}, defaultSetCookieOptions), { expires: new Date(Date.now() + ONE_YEAR_IN_MS) }));
            return Promise.resolve();
        },
        getItem: function (key) {
            var _a;
            var cookie = cookieStorageAdapter.get(key);
            return Promise.resolve((_a = cookie === null || cookie === void 0 ? void 0 : cookie.value) !== null && _a !== void 0 ? _a : null);
        },
        removeItem: function (key) {
            cookieStorageAdapter.delete(key);
            return Promise.resolve();
        },
        clear: function () {
            // TODO(HuiSF): follow up the implementation.
            throw new Error('This method has not implemented.');
        },
    };
};
