// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
import { Amplify, LocalStorage, CookieStorage, } from '@aws-amplify/core';
import { CognitoUserPoolsTokenProvider, cognitoCredentialsProvider, } from './auth';
export var DefaultAmplify = {
    configure: function (resourceConfig, libraryOptions) {
        CognitoUserPoolsTokenProvider.setAuthConfig(resourceConfig.Auth);
        cognitoCredentialsProvider.setAuthConfig(resourceConfig.Auth);
        var defaultLibraryOptions = {
            Auth: {
                tokenProvider: CognitoUserPoolsTokenProvider,
                credentialsProvider: cognitoCredentialsProvider,
            },
        };
        var updatedLibraryOptions = {};
        if (libraryOptions !== undefined) {
            updatedLibraryOptions = libraryOptions;
        }
        else {
            CognitoUserPoolsTokenProvider.setKeyValueStorage(resourceConfig.ssr
                ? new CookieStorage({
                    sameSite: 'strict',
                })
                : LocalStorage);
            updatedLibraryOptions = defaultLibraryOptions;
        }
        Amplify.configure(resourceConfig, updatedLibraryOptions);
    },
    getConfig: function () {
        return Amplify.getConfig();
    },
};
