"use strict";
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
Object.defineProperty(exports, "__esModule", { value: true });
exports.runWithAmplifyServerContext = void 0;
var tslib_1 = require("tslib");
var adapter_core_1 = require("@aws-amplify/core/internals/adapter-core");
/**
 * The low level function that supports framework specific helpers.
 * It creates an Amplify server context based on the input and runs the operation
 * with injecting the context, and finally returns the result of the operation.
 *
 * @param amplifyConfig The Amplify resource config.
 * @param libraryOptions The Amplify library options.
 * @param operation The operation to run with the server context created from
 *   `amplifyConfig` and `libraryOptions`.
 * @returns The result returned by the `operation`.
 */
var runWithAmplifyServerContext = function (amplifyConfig, libraryOptions, operation) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
    var contextSpec, result;
    return tslib_1.__generator(this, function (_a) {
        switch (_a.label) {
            case 0:
                contextSpec = (0, adapter_core_1.createAmplifyServerContext)(amplifyConfig, libraryOptions);
                return [4 /*yield*/, operation(contextSpec)];
            case 1:
                result = _a.sent();
                (0, adapter_core_1.destroyAmplifyServerContext)(contextSpec);
                return [2 /*return*/, result];
        }
    });
}); };
exports.runWithAmplifyServerContext = runWithAmplifyServerContext;
